# @summary
#   Describe what this class do!
#
#   Detailed summary info if suitable
#
#
class aes::squid_filter {
  case fact('os.name') {
    'RedHat': {
      firewalld_custom_service { 'squid':
        description => 'Squid proxy for filtered internet access',
        ports       => [
          { port => '3128',  protocol => 'tcp' },
        ],
      }

      @firewalld_rich_rule {
        default:
          service => 'squid',
          log     => false;

        'Accept squid in LiU networks without logging IPv4':
          zone   => 'liu',
          family => 'ipv4',
          action => 'accept';
        'Accept squid in LiU networks without logging IPv6':
          zone   => 'liu',
          family => 'ipv6',
          action => 'accept';
      }
    }
    'CentOS': {
      ::server_firewall::rules_file { '45-permit_squid.rules':
        # lint:ignore:strict_indent heredoc failing...
        content => @(EOF),
        service squid is tcp/3128

        policy chain INPUT is
          accept service:squid from class:liu-nets
        end policy
        |-EOF
        # lint:endignore:strict_indent
      }
    }
    default: {
      fail("${module_name} - Not supported for family ${fact('os.name')}.")
    }
  }

  package { 'squid' :
    ensure => 'present',
  }

  file { '/etc/squid/squid.conf':
    ensure  => file,
    mode    => '0644',
    owner   => root,
    group   => root,
    content => file("${module_name}/squid/squid.conf"),
  }

  file { '/usr/libexec/squid/helpers':
    ensure  => directory,
    recurse => true,
    purge   => true,
    force   => true,
    owner   => squid,
    group   => squid,
    mode    => '0644',
    source  => "puppet:///modules/${module_name}/squid/helpers",
    notify  => Service['squid'],
  }

  file { '/usr/libexec/squid/helpers/squid-url-rewrite.py':
    ensure => file,
    owner  => squid,
    group  => squid,
    mode   => '0755',
    source => "puppet:///modules/${module_name}/squid/helpers/squid-url-rewrite.py",
    notify => Service['squid'],
  }

  file { '/var/cache/squid' :
    ensure => directory,
    mode   => '0750',
    owner  => squid,
    group  => squid,
  }

  file { '/var/log/squid' :
    ensure => directory,
    mode   => '0750',
    owner  => squid,
    group  => squid,
  }

  file { '/var/lib/squid' :
    ensure => directory,
    mode   => '0750',
    owner  => squid,
    group  => squid,
  }

  exec { '/usr/lib64/squid/ssl_crtd -c -s /var/lib/squid/ssl_db' :
    user    => 'squid',
    group   => 'squid',
    creates => '/var/lib/squid/ssl_db',
  }

  # todo: logrotate
  service { 'squid' :
    ensure => 'running',
    enable => true,
  }
}
